summaryrefslogtreecommitdiffhomepage
path: root/pkg/sentry/strace/syscalls.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/sentry/strace/syscalls.go')
-rw-r--r--pkg/sentry/strace/syscalls.go9
1 files changed, 8 insertions, 1 deletions
diff --git a/pkg/sentry/strace/syscalls.go b/pkg/sentry/strace/syscalls.go
index 4513d1ba6..770a0d2b9 100644
--- a/pkg/sentry/strace/syscalls.go
+++ b/pkg/sentry/strace/syscalls.go
@@ -132,10 +132,17 @@ const (
// ItimerVal is a pointer to a struct itimerval.
ItimerVal
// ItimerVal is a pointer to a struct itimerval, formatted after
// syscall execution.
PostItimerVal
+ // ItimerSpec is a pointer to a struct itimerspec.
+ ItimerSpec
+
+ // PostItimerSpec is a pointer to a struct itimerspec, formatted after
+ // syscall execution.
+ PostItimerSpec
+
// Timeval is a pointer to a struct timeval, formatted before and after
// syscall execution.
Timeval
@@ -132,10 +132,17 @@ const (
// ItimerVal is a pointer to a struct itimerval.
ItimerVal
- // ItimerVal is a pointer to a struct itimerval, formatted after
+ // PostItimerVal is a pointer to a struct itimerval, formatted after
// syscall execution.
PostItimerVal